@@ -12,7 +12,6 @@ from django.conf import settings
 from django.core.management import call_command
 from django.db import DEFAULT_DB_ALIAS, ProgrammingError, connections
 from django.db.migrations import RunPython, RunSQL
-from six import PY2
 
 from .cache import Cache
 from .constants import (
@@ -21,7 +20,7 @@ from .constants import (
     EXPECTED_DATA_MIGRATION_ARGS,
 )
 from .operations import IgnoreMigration
-from .sql_analyser import analyse_sql_statements
+from .sql_analyser import analyse_sql_statements, get_sql_analyser_class
 from .utils import clean_bytes_to_str, get_migration_abspath, split_migration_path
 
 logger = logging.getLogger("django_migration_linter")
@@ -57,6 +56,8 @@ class MigrationLinter(object):
         exclude_migration_tests=None,
         quiet=None,
         warnings_as_errors=False,
+        no_output=False,
+        analyser_string=None,
     ):
         # Store parameters and options
         self.django_path = path
@@ -74,6 +75,11 @@ class MigrationLinter(object):
         self.only_unapplied_migrations = only_unapplied_migrations
         self.quiet = quiet or []
         self.warnings_as_errors = warnings_as_errors
+        self.no_output = no_output
+        self.sql_analyser_class = get_sql_analyser_class(
+            settings.DATABASES[self.database]["ENGINE"],
+            analyser_string=analyser_string,
+        )
 
         # Initialise counters
         self.reset_counters()
@@ -101,7 +107,13 @@ class MigrationLinter(object):
     def should_use_cache(self):
         return self.django_path and not self.no_cache
 
-    def lint_all_migrations(self, git_commit_id=None, migrations_file_path=None):
+    def lint_all_migrations(
+        self,
+        app_label=None,
+        migration_name=None,
+        git_commit_id=None,
+        migrations_file_path=None,
+    ):
         # Collect migrations
         migrations_list = self.read_migrations_list(migrations_file_path)
         if git_commit_id:
@@ -113,8 +125,22 @@ class MigrationLinter(object):
         sorted_migrations = sorted(
             migrations, key=lambda migration: (migration.app_label, migration.name)
         )
+
+        specific_target_migration = (
+            self.migration_loader.get_migration_by_prefix(app_label, migration_name)
+            if app_label and migration_name
+            else None
+        )
+
         for m in sorted_migrations:
-            self.lint_migration(m)
+            if app_label and migration_name:
+                if m == specific_target_migration:
+                    self.lint_migration(m)
+            elif app_label:
+                if m.app_label == app_label:
+                    self.lint_migration(m)
+            else:
+                self.lint_migration(m)
 
         if self.should_use_cache():
             self.new_cache.save()
@@ -139,17 +165,19 @@ class MigrationLinter(object):
             return
 
         sql_statements = self.get_sql(app_label, migration_name)
-        errors, ignored = analyse_sql_statements(
+        errors, ignored, warnings = analyse_sql_statements(
+            self.sql_analyser_class,
             sql_statements,
-            settings.DATABASES[self.database]["ENGINE"],
             self.exclude_migration_tests,
         )
 
-        err, ignored_data, warnings = self.analyse_data_migration(migration)
+        err, ignored_data, warnings_data = self.analyse_data_migration(migration)
         if err:
             errors += err
         if ignored_data:
             ignored += ignored_data
+        if warnings_data:
+            warnings += warnings_data
 
         if self.warnings_as_errors:
             errors += warnings
@@ -226,7 +254,8 @@ class MigrationLinter(object):
     def print_linting_msg(self, app_label, migration_name, msg, lint_result):
         if lint_result.value in self.quiet:
             return
-        print("({0}, {1})... {2}".format(app_label, migration_name, msg))
+        if not self.no_output:
+            print("({0}, {1})... {2}".format(app_label, migration_name, msg))
 
     def print_errors(self, errors):
         if MessageType.ERROR.value in self.quiet:
@@ -238,7 +267,8 @@ class MigrationLinter(object):
                 if err.get("column"):
                     error_str += ", column: {0}".format(err["column"])
                 error_str += ")"
-            print(error_str)
+            if not self.no_output:
+                print(error_str)
 
     def print_warnings(self, warnings):
         if MessageType.WARNING.value in self.quiet:
@@ -246,10 +276,12 @@ class MigrationLinter(object):
 
         for warning_details in warnings:
             warn_str = "\t{}".format(warning_details["msg"])
-            print(warn_str)
+            if not self.no_output:
+                print(warn_str)
 
     def print_summary(self):
-        print()
+        if self.no_output:
+            return
         print("*** Summary ***")
         print("Valid migrations: {}/{}".format(self.nb_valid, self.nb_total))
         print("Erroneous migrations: {}/{}".format(self.nb_erroneous, self.nb_total))
@@ -435,11 +467,7 @@ class MigrationLinter(object):
                 warning.append(issue)
 
         # Detect warning for argument naming convention
-        args_spec = (
-            inspect.getargspec(runpython.code)
-            if PY2
-            else inspect.getfullargspec(runpython.code)
-        )
+        args_spec = inspect.getfullargspec(runpython.code)
         if tuple(args_spec.args) != EXPECTED_DATA_MIGRATION_ARGS:
             issue = {
                 "code": "RUNPYTHON_ARGS_NAMING_CONVENTION",
@@ -596,15 +624,17 @@ class MigrationLinter(object):
             else:
                 sql_statements.append(runsql.sql)
 
-            sql_errors, sql_ignored = analyse_sql_statements(
+            sql_errors, sql_ignored, sql_warnings = analyse_sql_statements(
+                self.sql_analyser_class,
                 sql_statements,
-                settings.DATABASES[self.database]["ENGINE"],
                 self.exclude_migration_tests,
             )
             if sql_errors:
                 error += sql_errors
             if sql_ignored:
                 ignored += sql_ignored
+            if sql_warnings:
+                warning += sql_warnings
 
         # And analysse the reverse SQL
         if runsql.reversible and runsql.reverse_sql != RunSQL.noop:
@@ -624,14 +654,16 @@ class MigrationLinter(object):
             else:
                 sql_statements.append(runsql.reverse_sql)
 
-            sql_errors, sql_ignored = analyse_sql_statements(
+            sql_errors, sql_ignored, sql_warnings = analyse_sql_statements(
+                self.sql_analyser_class,
                 sql_statements,
-                settings.DATABASES[self.database]["ENGINE"],
                 self.exclude_migration_tests,
             )
             if sql_errors:
                 error += sql_errors
             if sql_ignored:
                 ignored += sql_ignored
+            if sql_warnings:
+                warning += sql_warnings
 
         return error, ignored, warning
