@@ -8,7 +8,7 @@ logger = logging.getLogger("django_migration_linter")
 
 def has_not_null_column(sql_statements, **kwargs):
     # TODO: improve to detect that the same column is concerned
-    ends_with_default = None
+    ends_with_default = False
     for sql in sql_statements:
         if "SET DEFAULT" in sql:
             ends_with_default = True
@@ -26,7 +26,9 @@ def has_not_null_column(sql_statements, **kwargs):
 def has_add_unique(sql_statements, **kwargs):
     regex_result = None
     for sql in sql_statements:
-        regex_result = re.search("ALTER TABLE (.*) ADD CONSTRAINT .* UNIQUE", sql)
+        regex_result = re.search(
+            "ALTER TABLE (.*) ADD CONSTRAINT .* UNIQUE", sql
+        ) or re.search('CREATE UNIQUE INDEX .* ON (".*?")', sql)
         if regex_result:
             break
     if not regex_result:
@@ -48,24 +50,28 @@ class BaseAnalyser(object):
             or re.search("ALTER TABLE .* RENAME TO", sql),
             "msg": "RENAMING tables",
             "mode": "one_liner",
+            "type": "error",
         },
         {
             "code": "NOT_NULL",
             "fn": has_not_null_column,
             "msg": "NOT NULL constraint on columns",
             "mode": "transaction",
+            "type": "error",
         },
         {
             "code": "DROP_COLUMN",
             "fn": lambda sql, **kw: re.search("DROP COLUMN", sql),
             "msg": "DROPPING columns",
             "mode": "one_liner",
+            "type": "error",
         },
         {
             "code": "DROP_TABLE",
             "fn": lambda sql, **kw: sql.startswith("DROP TABLE"),
             "msg": "DROPPING table",
             "mode": "one_liner",
+            "type": "error",
         },
         {
             "code": "RENAME_COLUMN",
@@ -73,6 +79,7 @@ class BaseAnalyser(object):
             or re.search("ALTER TABLE .* RENAME COLUMN", sql),
             "msg": "RENAMING columns",
             "mode": "one_liner",
+            "type": "error",
         },
         {
             "code": "ALTER_COLUMN",
@@ -84,12 +91,14 @@ class BaseAnalyser(object):
                 "You may ignore this migration.)"
             ),
             "mode": "one_liner",
+            "type": "error",
         },
         {
             "code": "ADD_UNIQUE",
             "fn": has_add_unique,
             "msg": "ADDING unique constraint",
             "mode": "transaction",
+            "type": "error",
         },
     ]
 
@@ -98,6 +107,7 @@ class BaseAnalyser(object):
     def __init__(self, exclude_migration_tests):
         self.exclude_migration_tests = exclude_migration_tests or []
         self.errors = []
+        self.warnings = []
         self.ignored = []
         self.migration_tests = update_migration_tests(
             self.base_migration_tests, self.migration_tests
@@ -113,21 +123,26 @@ class BaseAnalyser(object):
 
     @property
     def one_line_migration_tests(self):
-        return [test for test in self.migration_tests if test["mode"] == "one_liner"]
+        return (test for test in self.migration_tests if test["mode"] == "one_liner")
 
     @property
     def transaction_migration_tests(self):
-        return [test for test in self.migration_tests if test["mode"] == "transaction"]
+        return (test for test in self.migration_tests if test["mode"] == "transaction")
 
     def _test_sql(self, test, sql):
         if test["fn"](sql, errors=self.errors):
-            err = self.build_error_dict(migration_test=test, sql_statement=sql)
             if test["code"] in self.exclude_migration_tests:
-                logger.debug("Testing %s -- IGNORED", sql)
-                self.ignored.append(err)
+                action = "IGNORED"
+                list_to_add = self.ignored
+            elif test["type"] == "warning":
+                action = "WARNING"
+                list_to_add = self.warnings
             else:
-                logger.debug("Testing %s -- ERROR", sql)
-                self.errors.append(err)
+                action = "ERROR"
+                list_to_add = self.errors
+            logger.debug("Testing %s -- %s", sql, action)
+            err = self.build_error_dict(migration_test=test, sql_statement=sql)
+            list_to_add.append(err)
         else:
             logger.debug("Testing %s -- PASSED", sql)
 
