@@ -11,3 +11,5 @@ ALTER_COLUMN_DROP_NOT_NULL = "app_alter_column_drop_not_null"
 DROP_UNIQUE_TOGETHER = "app_unique_together"
 ADD_MANYTOMANY_FIELD = "app_add_manytomany_field"
 DATA_MIGRATIONS = "app_data_migrations"
+MAKE_NOT_NULL_WITH_DJANGO_DEFAULT = "app_make_not_null_with_django_default"
+MAKE_NOT_NULL_WITH_LIB_DEFAULT = "app_make_not_null_with_lib_default"
