@@ -1,6 +1,9 @@
 import unittest
 
-from django_migration_linter.sql_analyser import analyse_sql_statements
+from django_migration_linter.sql_analyser import (
+    analyse_sql_statements,
+    get_sql_analyser_class,
+)
 
 
 class SqlAnalyserTestCase(unittest.TestCase):
@@ -10,16 +13,32 @@ class SqlAnalyserTestCase(unittest.TestCase):
         if isinstance(sql, str):
             sql = sql.splitlines()
         return analyse_sql_statements(
-            sql_statements=sql, database_vendor=self.database_vendor
+            get_sql_analyser_class(self.database_vendor),
+            sql_statements=sql,
         )
 
-    def assertValidSql(self, sql):
-        errors, _ = self.analyse_sql(sql)
+    def assertValidSql(self, sql, allow_warnings=False):
+        errors, _, warnings = self.analyse_sql(sql)
         self.assertEqual(0, len(errors), "Found errors in sql: {}".format(errors))
+        if not allow_warnings:
+            self.assertEqual(
+                0, len(warnings), "Found warnings in sql: {}".format(errors)
+            )
 
-    def assertBackwardIncompatibleSql(self, sql):
-        errors, _ = self.analyse_sql(sql)
+    def assertBackwardIncompatibleSql(self, sql, code=None):
+        errors, _, _ = self.analyse_sql(sql)
         self.assertNotEqual(0, len(errors), "Found no errors in sql")
+        if code:
+            self.assertTrue(
+                any(err["code"] == code for err in errors),
+                "Didn't find error code {} in returned errors ({})".format(
+                    code, [err["code"] for err in errors]
+                ),
+            )
+
+    def assertWarningSql(self, sql):
+        _, _, warnings = self.analyse_sql(sql)
+        self.assertNotEqual(0, len(warnings), "Found no warnings in sql")
 
 
 class MySqlAnalyserTestCase(SqlAnalyserTestCase):
@@ -55,6 +74,16 @@ class MySqlAnalyserTestCase(SqlAnalyserTestCase):
         sql = "ALTER TABLE `app_unique_together_a` DROP INDEX `app_unique_together_a_int_field_char_field_979ac7d8_uniq`;"
         self.assertValidSql(sql)
 
+    def test_unique_index(self):
+        sql = 'CREATE UNIQUE INDEX "index_name" ON "table" ("col1", "col2");'
+        self.assertBackwardIncompatibleSql(sql, "ADD_UNIQUE")
+
+        sql = [
+            'CREATE TABLE "table" ("col1" integer, "col2" integer);',
+            'CREATE UNIQUE INDEX "index_name" ON "table" ("col1", "col2");',
+        ]
+        self.assertValidSql(sql)
+
     def test_add_many_to_many_field(self):
         sql = [
             "CREATE TABLE `app_add_manytomany_field_b_many_to_many`(`id` integer AUTO_INCREMENT NOT NULL PRIMARY KEY, `b_id` integer NOT NULL, `a_id` integer NOT NULL);",
@@ -138,6 +167,16 @@ class SqliteAnalyserTestCase(SqlAnalyserTestCase):
         sql = 'DROP INDEX "app_unique_together_a_int_field_char_field_979ac7d8_uniq";'
         self.assertValidSql(sql)
 
+    def test_unique_index(self):
+        sql = 'CREATE UNIQUE INDEX "index_name" ON "table" ("col1", "col2");'
+        self.assertBackwardIncompatibleSql(sql, "ADD_UNIQUE")
+
+        sql = [
+            'CREATE TABLE "table" ("col1" integer, "col2" integer);',
+            'CREATE UNIQUE INDEX "index_name" ON "table" ("col1", "col2");',
+        ]
+        self.assertValidSql(sql)
+
     def test_add_many_to_many_field(self):
         sql = [
             'CREATE TABLE "app_add_manytomany_field_b_many_to_many"("id" integer NOT NULL PRIMARY KEY AUTOINCREMENT, "b_id" integer NOT NULL REFERENCES "app_add_manytomany_field_b"("id") DEFERRABLE INITIALLY DEFERRED, "a_id" integer NOT NULL REFERENCES "app_add_manytomany_field_a"("id") DEFERRABLE INITIALLY DEFERRED);',
@@ -163,6 +202,21 @@ class PostgresqlAnalyserTestCase(SqlAnalyserTestCase):
         ]
         self.assertValidSql(sql)
 
+    def test_field_to_not_null_with_dropped_default(self):
+        sql = [
+            'ALTER TABLE "api_example_example" ALTER COLUMN "foo_id" SET DEFAULT 42;',
+            'UPDATE "example_example" SET "foo_id" = 42 WHERE "foo_id" IS NULL;',
+            'ALTER TABLE "example_example" ALTER COLUMN "foo_id" SET NOT NULL;',
+            'ALTER TABLE "example_example" ALTER COLUMN "foo_id" DROP DEFAULT;',
+        ]
+        self.assertBackwardIncompatibleSql(sql)
+
+    def test_onetoonefield_to_not_null(self):
+        sql = [
+            'ALTER TABLE "example_example" ALTER COLUMN "foo" SET NOT NULL;',
+        ]
+        self.assertBackwardIncompatibleSql(sql)
+
     def test_drop_not_null(self):
         sql = 'ALTER TABLE "app_alter_column_drop_not_null_a" ALTER COLUMN "not_null_field" DROP NOT NULL;'
         self.assertValidSql(sql)
@@ -174,6 +228,16 @@ class PostgresqlAnalyserTestCase(SqlAnalyserTestCase):
         sql = 'ALTER TABLE "app_unique_together_a" DROP CONSTRAINT "app_unique_together_a_int_field_char_field_979ac7d8_uniq";'
         self.assertValidSql(sql)
 
+    def test_unique_index(self):
+        sql = 'CREATE UNIQUE INDEX "index_name" ON "table" ("col1", "col2");'
+        self.assertBackwardIncompatibleSql(sql, "ADD_UNIQUE")
+
+        sql = [
+            'CREATE TABLE "table" ("col1" integer, "col2" integer);',
+            'CREATE UNIQUE INDEX "index_name" ON "table" ("col1", "col2");',
+        ]
+        self.assertValidSql(sql)
+
     def test_add_many_to_many_field(self):
         sql = [
             'CREATE TABLE "app_add_manytomany_field_b_many_to_many"("id" serial NOT NULL PRIMARY KEY, "b_id" integer NOT NULL, "a_id" integer NOT NULL);',
@@ -183,7 +247,7 @@ class PostgresqlAnalyserTestCase(SqlAnalyserTestCase):
             'CREATE INDEX "app_add_manytomany_field_b_many_to_many_b_id_953b185b" ON "app_add_manytomany_field_b_many_to_many"("b_id");',
             'CREATE INDEX "app_add_manytomany_field_b_many_to_many_a_id_4b44832a" ON "app_add_manytomany_field_b_many_to_many"("a_id");',
         ]
-        self.assertValidSql(sql)
+        self.assertValidSql(sql, allow_warnings=True)
 
     def test_make_column_not_null_with_django_default(self):
         sql = [
@@ -203,3 +267,46 @@ class PostgresqlAnalyserTestCase(SqlAnalyserTestCase):
             'ALTER TABLE "app_drop_default_a" ALTER COLUMN "col" SET DEFAULT `\'empty\';',
         ]
         self.assertValidSql(sql)
+
+    def test_create_index_non_concurrently(self):
+        sql = "CREATE INDEX ON films ((lower(title)));"
+        self.assertWarningSql(sql)
+        sql = "CREATE UNIQUE INDEX title_idx ON films (title);"
+        self.assertWarningSql(sql)
+
+    def test_create_index_non_concurrently_with_table_creation(self):
+        sql = [
+            'CREATE TABLE "films" ("title" text);',
+            'CREATE INDEX ON "films" ((lower("title")));',
+        ]
+        self.assertValidSql(sql)
+        sql = [
+            'CREATE TABLE "some_table" ("title" text);',
+            'CREATE INDEX ON "films" ((lower("title")));',
+        ]
+        self.assertWarningSql(sql)
+        sql = [
+            'CREATE TABLE "films" ("title" text);',
+            'CREATE INDEX ON "some_table" ((lower("title")));',
+        ]
+        self.assertWarningSql(sql)
+
+    def test_create_index_concurrently(self):
+        sql = "CREATE INDEX CONCURRENTLY ON films (lower(title));"
+        self.assertValidSql(sql)
+        sql = "CREATE UNIQUE INDEX CONCURRENTLY title_idx ON films (title);"
+        self.assertValidSql(sql)
+
+    def test_drop_index_non_concurrently(self):
+        sql = "DROP INDEX ON films"
+        self.assertWarningSql(sql)
+
+    def test_drop_index_concurrently(self):
+        sql = "DROP INDEX CONCURRENTLY ON films;"
+        self.assertValidSql(sql)
+
+    def test_reindex(self):
+        sql = "REINDEX INDEX my_index;"
+        self.assertWarningSql(sql)
+        sql = "REINDEX TABLE my_table;"
+        self.assertWarningSql(sql)
